"""
Configuration hooks for pytest. Normally this wouldn't be necessary,
but since pytest-rst is used, we want to clean-up files generated by
running documentation tests. Therefore, this hook, which simply
calls the `clean_up` method of the `FILE_REGISTRY` instance.
"""
from contextlib import suppress

import pytest
from faker_file.registry import FILE_REGISTRY

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2022-2025 Artur Barseghyan"
__license__ = "MIT"
__all__ = (
    "pytest_runtest_setup",
    "pytest_runtest_teardown",
)


def pytest_collection_modifyitems(config, items):
    """Modify test items during collection."""
    for item in items:
        with suppress(ImportError):
            from pytest_rst import RSTTestItem

            if isinstance(item, RSTTestItem):
                # Dynamically add marker to RSTTestItem tests
                item.add_marker(pytest.mark.documentation)


def pytest_runtest_setup(item):
    """Setup before test runs."""
    with suppress(ImportError):
        from pytest_rst import RSTTestItem

        if isinstance(item, RSTTestItem):
            # Insert the setup logic here
            pass  # Replace with your desired setup actions


def pytest_runtest_teardown(item, nextitem):
    """Clean up after test ends."""
    with suppress(ImportError):
        from pytest_rst import RSTTestItem

        if isinstance(item, RSTTestItem):
            FILE_REGISTRY.clean_up()
